@@ -41,7 +41,7 @@ K_EXPORT_PLUGIN( DSPluginFactory(aboutdata) )
 
 
 RootedTreePlugin::RootedTreePlugin(QObject* parent, const QList< QVariant >& /*args*/ )
-    : DataStructurePluginInterface(DSPluginFactory::componentData(), parent)
+    : DataStructureBackendInterface(DSPluginFactory::componentData(), parent)
 {
 }
 
@@ -75,7 +75,7 @@ QLayout* RootedTreePlugin::dataExtraProperties(DataPtr /*node*/, QWidget* /*pare
 
 QLayout*  RootedTreePlugin::pointerExtraProperties(PointerPtr arg1, QWidget* arg2) const
 {
-    return  DataStructurePluginInterface::pointerExtraProperties(arg1, arg2);
+    return  DataStructureBackendInterface::pointerExtraProperties(arg1, arg2);
 }
 
 QLayout*  RootedTreePlugin::dataStructureExtraProperties(DataStructurePtr graph, QWidget* parentWidget) const
@@ -101,7 +101,8 @@ bool RootedTreePlugin::canConvertFrom(Document* doc) const
     QSet<Data*> cycles;
     QQueue<DataPtr> queue;
     foreach (DataStructurePtr ds, doc->dataStructures()){
-        foreach(DataPtr p, ds->dataList()){
+        //FIXME only default data type considered
+        foreach(DataPtr p, ds->dataList(0)){
             if (visited.contains(p.get())) {
                 continue;
             }
